# GitHub Repository Curation

## Step 1

### PLs

```
python
go
c++
java
typescript
php
rust
```

### GitHub searching

Search at: https://github.com/search?

```
language:{LANGUAGE} stars:>=100 license:mit license:apache-2.0 pushed:>=2024-01-01 size:128..32000 sort:stars
```

### Find repositories by package rankings

Can also look at package ranking websites such as https://pypistats.org/top

## Step 2

Select 10 repositories based on the following quality criteria:
1. Uses unit tests and CI/CD
2. Is a package
3. Diversify over topics (developer tool, machine learning, etc)
4. Has enough code (hopefully 10+ files)
5. Better be pure in one language

## Step 3

Follow the `lists.json` to fill the repositories.
